"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const joi_1 = __importDefault(require("@hapi/joi"));
const lodash_1 = require("lodash");
const schema_1 = require("./schema");
class Config {
    constructor() {
        this.config = {};
    }
    load(server, options) {
        this.reset();
        const { value, error } = joi_1.default.validate(options, schema_1.configSchema);
        if (error) {
            this.error = error;
            return;
        }
        const routeSettings = server.table().map(item => item.settings);
        for (const routeSetting of routeSettings) {
            const result = joi_1.default.validate(routeSetting.plugins.pagination, schema_1.routeSchema);
            if (result.error) {
                this.error = result.error;
                return;
            }
        }
        this.config = value;
    }
    reset() {
        this.error = undefined;
        this.config = {};
    }
    get(key, defaultValue) {
        return lodash_1.get(this.config, key, defaultValue);
    }
    set(key, value) {
        lodash_1.set(this.config, key, value);
    }
    getError() {
        return this.error;
    }
    hasError() {
        return !!this.error;
    }
}
exports.config = new Config();
//# sourceMappingURL=index.js.map