"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const boom_1 = __importDefault(require("@hapi/boom"));
const MediaType = __importStar(require("media-type"));
const paginator_1 = require("../pagination/paginator");
const parser_1 = require("../parser");
const validator_1 = require("../validator");
const handleAcceptHeader = request => {
    if (request.headers.accept.indexOf("application/vnd.api+json") === -1) {
        throw boom_1.default.notAcceptable('Expected accept header to be "application/vnd.api+json"');
    }
};
const handleContentTypeHeader = request => {
    const contentMedia = MediaType.fromString(request.headers["content-type"]);
    if (contentMedia.parameters.charset === "UTF-8") {
        delete contentMedia.parameters.charset;
    }
    const hasInvalidType = contentMedia.type !== "application";
    const hasInvalidSubType = contentMedia.subtype !== "vnd.api";
    const hasInvalidParameters = Object.keys(contentMedia.parameters).length > 0;
    if (hasInvalidType || hasInvalidSubType || hasInvalidParameters) {
        throw boom_1.default.unsupportedMediaType('Expected content-type header to be "application/vnd.api+json"');
    }
};
exports.onPreHandler = (request, h) => {
    if (request.headers["content-type"]) {
        handleContentTypeHeader(request);
    }
    else if (request.headers.accept) {
        handleAcceptHeader(request);
    }
    request.jsonapi = {
        include: parser_1.Parser.include(request),
        sort: parser_1.Parser.sort(request),
        filter: parser_1.Parser.filter(request),
        pagination: parser_1.Parser.pagination(request),
        fields: parser_1.Parser.fields(request),
    };
    paginator_1.paginator.onPreHandler(request, h);
    return validator_1.onPreHandler(request, h);
};
//# sourceMappingURL=pre-handler.js.map