"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = require("../config");
const helpers_1 = require("../helpers");
const setHeader = value => {
    const header = "application/vnd.api+json";
    value.headers["content-type"] = header;
    value.headers.accept = header;
};
const handleBoom = (request, meta) => {
    const { response } = request;
    const { output } = response;
    output.payload = helpers_1.wrapResponse({
        errors: [
            {
                title: output.payload.error,
                status: output.statusCode,
                detail: output.payload.message,
            },
        ],
        meta: { id: request.info.id, ...meta },
    });
    if (response.data) {
        if (output.statusCode === 500) {
            request.log("error", response.data instanceof Buffer ? response.data.toString() : response.data);
        }
    }
    setHeader(output);
};
const handleJoi = (request, meta) => {
    const { response } = request;
    const { output } = response;
    const getErrorMessage = details => `${details.message} (${details.path.join(".")})`;
    const error = {
        title: output.payload.error,
        status: output.statusCode,
        detail: output.payload.message,
    };
    if (response.details) {
        error.details = response.details.map(getErrorMessage).join(", ");
    }
    output.payload = helpers_1.wrapResponse({
        errors: [error],
        meta: { id: request.info.id, ...meta },
    });
    setHeader(output);
};
const handleSuccess = (request, meta) => {
    const { response } = request;
    if (response.source) {
        if (response.source.errors) {
            response.source = helpers_1.wrapResponse(response.source);
        }
        else {
            response.source =
                response.source.links || response.source.data
                    ? helpers_1.wrapResponse(response.source)
                    : helpers_1.wrapResponse({ data: response.source });
        }
        response.source.meta = { ...response.source.meta, id: request.info.id, ...meta };
    }
    setHeader(response);
};
exports.onPreResponse = (request, h) => {
    const meta = config_1.config.get("meta");
    if (request.method === "options") {
        return h.continue;
    }
    if (request.response.isJoi) {
        handleJoi(request, meta);
    }
    else if (request.response.isBoom) {
        handleBoom(request, meta);
    }
    else {
        handleSuccess(request, meta);
    }
    return h.continue;
};
//# sourceMappingURL=pre-response.js.map