"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const boom_1 = __importDefault(require("@hapi/boom"));
const hoek_1 = __importDefault(require("@hapi/hoek"));
const qs = __importStar(require("querystring"));
const config_1 = require("../../config");
class Strategy {
    setRequest(request) {
        this.request = request;
    }
    getResults() {
        const { source } = this.request.response;
        const results = Array.isArray(source) ? source : source.results;
        hoek_1.default.assert(Array.isArray(results), "The results must be an array");
        return { source, results };
    }
    setQueryParameter(name, defaultValue) {
        let value = 0;
        if (this.request.query[name] || this.request.query[name] === 0) {
            value = parseInt(this.request.query[name], 10);
            if (isNaN(value)) {
                throw boom_1.default.badRequest(`Invalid ${name}`);
            }
        }
        this.request.query[name] = value || defaultValue;
    }
    getFullUri(query) {
        const baseUri = `${config_1.config.get("pagination.uri")}${this.request.url.pathname}?`;
        const baseQuery = { ...this.request.query, ...this.request.orig.query };
        return baseUri + qs.stringify(hoek_1.default.applyToDefaults(baseQuery, query));
    }
}
exports.Strategy = Strategy;
//# sourceMappingURL=strategy.js.map