"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class Parser {
    static fields(request) {
        const pattern = /fields\[(.*?)\]/;
        const matches = [];
        for (const [key, value] of Object.entries(request.query)) {
            if (RegExp(pattern).test(key)) {
                matches.push({
                    type: key.match(/\[(.*?)\]/)[1],
                    fields: value.split(","),
                });
            }
        }
        return matches;
    }
    static filter(request) {
        const pattern = /filter\[(.*?)\]/;
        const matches = [];
        for (const [key, value] of Object.entries(request.query)) {
            if (RegExp(pattern).test(key)) {
                matches.push({
                    field: key.match(/\[(.*?)\]/)[1],
                    value,
                });
            }
        }
        return matches;
    }
    static include(request) {
        const parameters = request.query.include || "";
        return parameters.split(",").map(parameter => ({
            relationship: parameter,
        }));
    }
    static pagination(request) {
        const allowed = ["number", "size", "offset", "limit", "cursor"];
        const pattern = /page\[(.*?)\]/;
        const matches = {};
        for (const [key, value] of Object.entries(request.query)) {
            if (RegExp(pattern).test(key)) {
                const parameter = key.match(/\[(.*?)\]/)[1];
                if (allowed.includes(parameter)) {
                    matches[parameter] = +value;
                }
            }
        }
        return matches;
    }
    static sort(request) {
        const parameters = request.query.sort || "";
        return parameters.split(",").map(parameter => ({
            field: parameter.startsWith("-") ? parameter.substr(1) : parameter,
            ascending: !parameter.startsWith("-"),
        }));
    }
}
exports.Parser = Parser;
//# sourceMappingURL=parser.js.map