"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const ajv_1 = __importDefault(require("ajv"));
const lodash_1 = require("lodash");
const mapErrors = (type, errors) => {
    return errors.map(error => {
        const report = {
            status: 422,
            source: { pointer: error.schemaPath },
            title: error.keyword,
        };
        if (error.message) {
            report.detail = error.message;
        }
        if (error.dataPath) {
            report.source.parameter = error.dataPath;
        }
        if (type === "query" && error.params.additionalProperty) {
            report.title = "Invalid Query Parameter";
            report.detail = `The endpoint does not have a '${error.params.additionalProperty}' query parameter.`;
        }
        return report;
    });
};
exports.onPreHandler = (request, h) => {
    const config = lodash_1.get(request.route.settings.plugins, "jsonapi.validate");
    if (!config) {
        return h.continue;
    }
    const ajv = new ajv_1.default();
    for (const type of ["headers", "params", "query", "payload"]) {
        const schema = config[type];
        if (schema) {
            if (!ajv.validate(schema, request[type])) {
                return h
                    .response({
                    errors: ajv.errors ? mapErrors(type, ajv.errors) : [],
                })
                    .code(422)
                    .takeover();
            }
        }
    }
    return h.continue;
};
//# sourceMappingURL=validator.js.map